@@ -8,10 +8,10 @@ class Moment(IntEnum):
     moment to execute it among the three main stages: 
 
     - Moment.BEFORE
-    - Moment.ON_FILE
+    - Moment.ON_ITEM
     - Moment.AFTER
 
     """
     BEFORE = 0
-    ON_FILE = 1
+    ON_ITEM = 1
     AFTER = 2
